@@ -767,7 +767,7 @@ def test_image_extraction2(url, name):
             "tika-918137.pdf",
         ),
         (
-            "https://unglueit-files.s3.amazonaws.com/ebf/7552c42e9280b4476e59e77acc0bc812.pdf",
+            "https://github.com/user-attachments/files/22596566/7552c42e9280b4476e59e77acc0bc812.pdf",
             "7552c42e9280b4476e59e77acc0bc812.pdf",
         ),
     ],
